#### Table of Contents

1. [Overview](#overview)
2. [Module Description - What the module does and why it is useful](#module-description)
3. [Setup - The basics of getting started with rancher](#setup)
4. [Usage - Configuration options and additional functionality](#usage)
5. [Reference - An under-the-hood peek at what the module is doing and how](#reference)

## Overview

A module to install the [Rancher](http://rancher.com/) server and accompanying agents on supported operating systems.

## Module Description

Rancher is a complete platform for running containers. Rancher supports both Kubernetes and Docker Swarm, making it simple to run any containerized application on any infrastructure. With this Puppet module you can easily setup Rancher on your own Puppet managed hosts.

## Setup

The module requires Docker to be running on the hosts. For this you can use the Puppet [Docker module](https://forge.puppetlabs.com/puppetlabs/docker_platform) or any other means. If using the docker module this is as simple as:

```puppet
class { 'docker': }
```

## Usage

First you are likely to want to install a new rancher server. This is as
simple as:

```puppet
class { 'rancher:server': }
```

It is also possible to specify a custom port for the server to run on:

```puppet
class { 'rancher:server':
  port => 9090,
}
```

Once the server is up and running and you can retrieve a registration
token (from the web interface or from the API) you can bootstrap Rancher
agents.

```puppet
class { 'rancher':
  registration_url => 'http://127.0.0.1:8080/v1/scripts/DB121CFBA836F9493653:1434085200000:2ZOwUMd6fIzz44efikGhBP1veo',
}
```

The class will use the ipaddress from `facter ipaddress` to register the
agent, if this is not correct you can override it like so:

```puppet
class { 'rancher':
  registration_url => 'http://127.0.0.1:8080/v1/scripts/DB121CFBA836F9493653:1434085200000:2ZOwUMd6fIzz44efikGhBP1veo',
  agent_address    => $::ipaddress_eth1,
}
```

## Reference

[Full API reference documentation](http://puppetlabs.github.io/puppetlabs-rancher/) is available as generated by [Puppet Strings](https://github.com/puppetlabs/puppetlabs-strings).
